//--------------------------------------------------------------
// File     : stm32_ub_m24c02.c
// Datum    : 07.03.2013
// Version  : 1.0
// Autor    : UB
// EMail    : mc-4u(@)t-online.de
// Web      : www.mikrocontroller-4u.de
// CPU      : STM32F4
// IDE      : CooCox CoIDE 1.7.0
// Module   : STM32_UB_I2C1
// Funktion : M24C02 (I2C-EEprom, 256 Byte)
//
// Hinweis  : Settings :
//            I2C-Slave-ADR = [0xA0 - 0xAE]
//            FRQ-Max = 10kHz
//            I2C1 [SCL=PB6, SDA=PB7]
//--------------------------------------------------------------


//--------------------------------------------------------------
// Includes
//--------------------------------------------------------------
#include "stm32_ub_m24c02.h"
#include "stm32_ub_i2c1.h"




//--------------------------------------------------------------
// Initialisierung vom M24C02
// slave : [M24C02_0 bis M24C02_7]
//
// Return_wert :
//  -> ERROR   , wenn M24C02 nicht gefunden wurde
//  -> SUCCESS , wenn M24C02 gefunden wurde
//--------------------------------------------------------------
ErrorStatus UB_M24C02_Init(I2C_ADR_M24C02_t slave)
{
  ErrorStatus ret_wert=ERROR;
  int16_t wert;

  // Init vom I2C-1
  UB_I2C1_Init();
  // zum Test ein Byte auslesen
  wert=UB_I2C1_ReadByte(slave, 0x00);
  // test ob lesen erfolgreich
  if(wert>=0) ret_wert=SUCCESS;   

  return(ret_wert);
}


//--------------------------------------------------------------
// Auslesen einer Adresse aus dem EEprom
// slave : [M24C02_0 bis M24C02_7]
// adr   : [0 bis 255]
//
// Return_wert :
//  0...255 , Bytewert der gelesen wurde
//  < 0     , Error
//-------------------------------------------------------------- 
int16_t UB_M24C02_ReadByte(I2C_ADR_M24C02_t slave, uint8_t adr)
{
  int16_t ret_wert=0;

  ret_wert=UB_I2C1_ReadByte(slave, adr);

  // kleine Pause
  if(ret_wert>=0) UB_I2C1_Delay(UB_M24C02_RD_DELAY);

  return(ret_wert);
}


//--------------------------------------------------------------
// Beschreiben einer Adresse vom EEprom
// slave : [M24C02_0 bis M24C02_7]
// adr   : [0 bis 255]
// wert  : [0 bis 255]
//
// Return_wert :
//    0   , Ok
//  < 0   , Error
//--------------------------------------------------------------
int16_t UB_M24C02_WriteByte(I2C_ADR_M24C02_t slave, uint8_t adr, uint8_t wert)
{
  int16_t ret_wert=0;

  ret_wert=UB_I2C1_WriteByte(slave, adr, wert);

  // kleine Pause
  if(ret_wert>=0) UB_I2C1_Delay(UB_M24C02_WR_DELAY);

  return(ret_wert);
}

